==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/fa-IR/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'لوازم جانبی بررسی شد',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'دارایی ثبت شد
',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'تأیید ورود لوازم جانبی',
    'Confirm_Asset_Checkin' => 'تأیید ورود دارایی
',
    'Confirm_accessory_delivery' => 'تاییدیه تحویل لوازم جانبی',
    'Confirm_asset_delivery' => 'تاییدیه تحویل دارایی
',
    'Confirm_consumable_delivery' => 'تاییدیه تحویل مصرفی
',
    'Confirm_license_delivery' => 'تاییدیه تحویل مجوز
',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'روزها',
    'Expected_Checkin_Date' => 'دارایی‌ای که برای شما بررسی شده است باید دوباره در تاریخ :date بررسی شود',
    'Expected_Checkin_Notification' => 'یادآوری: :نام مهلت اعلام حضور نزدیک است
',
    'Expected_Checkin_Report' => 'گزارش بررسی دارایی مورد انتظار
',
    'Expiring_Assets_Report' => 'گزارش دارایی های معوق',
    'Expiring_Licenses_Report' => 'گزارش مجوزهای منقضی شده',
    'Item_Request_Canceled' => 'درخواست مورد لغو شد',
    'Item_Requested' => 'مورد درخواست شده',
    'License_Checkin_Notification' => 'مجوز بررسی شد
',
    'License_Checkout_Notification' => 'License checked out',
    'Low_Inventory_Report' => 'گزارش موجودی کم',
    'a_user_canceled' => 'یک کاربر یک درخواست اقساط در وب سایت را لغو کرده است',
    'a_user_requested' => 'یک کاربر یک مورد را در وبسایت درخواست کرده است',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'نام لوازم جانبی:',
    'additional_notes' => 'یادداشت های اضافی:',
    'admin_has_created' => 'یک مدیر یک حساب کاربری برای شما در وب سایت وب ایجاد کرده است.',
    'asset' => 'دارایی:',
    'asset_name' => 'نام دارایی',
    'asset_requested' => 'دارایی درخواست شد',
    'asset_tag' => 'نام دارایی',
    'assets_warrantee_alert' => 'دارایی :count با گارانتی منقضی در روزهای بعدی: آستانه وجود دارد.',
    'assigned_to' => 'اختصاص یافته به',
    'best_regards' => 'با احترام،',
    'canceled' => 'لغو شد:',
    'checkin_date' => 'تاریخ ورود:',
    'checkout_date' => 'چک کردن تاریخ:',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'لطفا روی لینک زیر کلیک کنید تا تأیید کنید که لوازم جانبی را دریافت کرده اید.',
    'click_on_the_link_asset' => 'لطفا روی لینک زیر کلیک کنید تا تأیید کنید که دارایی را دریافت کرده اید.',
    'click_to_confirm' => 'لطفا برای پیوستن به این لینک کلیک کنید تا حساب خود را تایید کنید:',
    'current_QTY' => 'QTY فعلی',
    'days' => 'روزها',
    'expecting_checkin_date' => 'تاریخ انتظار انتظار:',
    'expires' => 'منقضی می شود',
    'hello' => 'سلام',
    'hi' => 'سلام',
    'i_have_read' => 'من شرایط استفاده را خوانده ام و موافقم و این مورد را دریافت کرده ام.',
    'inventory_report' => 'Inventory Report',
    'item' => 'مورد:',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'مجوز :count در روزهای بعدی :threshold منقضی می شود.|مجوزهای :count در روزهای بعدی :threshold منقضی می شوند.',
    'link_to_update_password' => 'برای به روزرسانی لطفا بر روی لینک زیر کلیک کنید: web password:',
    'login' => 'ورود:',
    'login_first_admin' => 'با نصب مجدد Snipe-IT جدید خود به سیستم وارد شوید',
    'low_inventory_alert' => 'آیتم :count وجود دارد که زیر حداقل موجودی است یا به زودی کم می شود.',
    'min_QTY' => 'حداقل QTY',
    'name' => 'نام',
    'new_item_checked' => 'یک آیتم جدید تحت نام شما چک شده است، جزئیات زیر است.',
    'notes' => 'نت ها',
    'password' => 'کلمه عبور:',
    'password_reset' => 'تنظیم مجدد رمز عبور',
    'read_the_terms' => 'لطفا شرایط استفاده زیر را بخوانید.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'درخواست شده:',
    'reset_link' => 'رمز عبور خود را بازنشانی کنید',
    'reset_password' => 'برای تغییر رمز عبور اینجا کلیک کنید:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'سریال',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'تامین کننده',
    'tag' => 'برچسب',
    'test_email' => 'ایمیل تست از Snipe-IT',
    'test_mail_text' => 'این آزمون از سیستم مدیریت دارایی Snipe-IT است. اگر شما این کار را کردید، ایمیل کار می کند :)',
    'the_following_item' => 'مورد زیر مورد بررسی قرار گرفته است:',
    'to_reset' => 'برای بازنشانی: رمز عبور وب، این فرم را تکمیل کنید:',
    'type' => 'تایپ کنید',
    'upcoming-audits' => 'دارایی :count وجود دارد که در روزهای :threshold برای حسابرسی ارائه می شود.',
    'user' => 'کاربر',
    'username' => 'نام کاربری',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'خوش آمدید نام',
    'welcome_to' => 'به وب سایت خوش آمدید',
    'your_assets' => 'دارایی های خود را مشاهده کنید
',
    'your_credentials' => 'مدارک Snipe-IT شما',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/fa-IR/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'لوازم جانبی بررسی شد',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'دارایی ثبت شد
',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'تأیید ورود لوازم جانبی',
    'Confirm_Asset_Checkin' => 'تأیید ورود دارایی
',
    'Confirm_accessory_delivery' => 'تاییدیه تحویل لوازم جانبی',
    'Confirm_asset_delivery' => 'تاییدیه تحویل دارایی
',
    'Confirm_consumable_delivery' => 'تاییدیه تحویل مصرفی
',
    'Confirm_license_delivery' => 'تاییدیه تحویل مجوز
',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'روزها',
    'Expected_Checkin_Date' => 'دارایی‌ای که برای شما بررسی شده است باید دوباره در تاریخ :date بررسی شود',
    'Expected_Checkin_Notification' => 'یادآوری: :نام مهلت اعلام حضور نزدیک است
',
    'Expected_Checkin_Report' => 'گزارش بررسی دارایی مورد انتظار
',
    'Expiring_Assets_Report' => 'گزارش دارایی های معوق',
    'Expiring_Licenses_Report' => 'گزارش مجوزهای منقضی شده',
    'Item_Request_Canceled' => 'درخواست مورد لغو شد',
    'Item_Requested' => 'مورد درخواست شده',
    'License_Checkin_Notification' => 'مجوز بررسی شد
',
    'License_Checkout_Notification' => 'License checked out',
    'Low_Inventory_Report' => 'گزارش موجودی کم',
    'a_user_canceled' => 'یک کاربر یک درخواست اقساط در وب سایت را لغو کرده است',
    'a_user_requested' => 'یک کاربر یک مورد را در وبسایت درخواست کرده است',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'نام وسیله',
    'additional_notes' => 'یادداشت های اضافی',
    'admin_has_created' => 'یک مدیر یک حساب کاربری برای شما در وب سایت وب ایجاد کرده است.',
    'asset' => 'دارایی',
    'asset_name' => 'نام دارایی',
    'asset_requested' => 'دارایی درخواست شد',
    'asset_tag' => 'نام دارایی',
    'assets_warrantee_alert' => 'دارایی :count با گارانتی منقضی در روزهای بعدی: آستانه وجود دارد.',
    'assigned_to' => 'اختصاص یافته به',
    'best_regards' => 'با احترام،',
    'canceled' => 'لغو شد',
    'checkin_date' => 'تاریخ ورود
',
    'checkout_date' => 'چک کردن تاریخ',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'لطفا روی لینک زیر کلیک کنید تا تأیید کنید که لوازم جانبی را دریافت کرده اید.',
    'click_on_the_link_asset' => 'لطفا روی لینک زیر کلیک کنید تا تأیید کنید که دارایی را دریافت کرده اید.',
    'click_to_confirm' => 'لطفا برای پیوستن به این لینک کلیک کنید تا حساب خود را تایید کنید:',
    'current_QTY' => 'QTY فعلی',
    'days' => 'روزها',
    'expecting_checkin_date' => ' چک در تاریخ را پر کنید',
    'expires' => 'منقضی می شود',
    'hello' => 'سلام',
    'hi' => 'سلام',
    'i_have_read' => 'من شرایط استفاده را خوانده ام و موافقم و این مورد را دریافت کرده ام.',
    'inventory_report' => 'Inventory Report',
    'item' => 'مورد',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'مجوز :count در روزهای بعدی :threshold منقضی می شود.|مجوزهای :count در روزهای بعدی :threshold منقضی می شوند.',
    'link_to_update_password' => 'برای به روزرسانی لطفا بر روی لینک زیر کلیک کنید: web password:',
    'login' => 'ورود:',
    'login_first_admin' => 'با نصب مجدد Snipe-IT جدید خود به سیستم وارد شوید',
    'low_inventory_alert' => 'آیتم :count وجود دارد که زیر حداقل موجودی است یا به زودی کم می شود.',
    'min_QTY' => 'حداقل QTY',
    'name' => 'نام',
    'new_item_checked' => 'یک آیتم جدید تحت نام شما چک شده است، جزئیات زیر است.',
    'notes' => 'نت ها',
    'password' => 'رمز عبور',
    'password_reset' => 'تنظیم مجدد رمز عبور',
    'read_the_terms' => 'لطفا شرایط استفاده زیر را بخوانید.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'در خواست شده',
    'reset_link' => 'رمز عبور خود را بازنشانی کنید',
    'reset_password' => 'برای تغییر رمز عبور اینجا کلیک کنید:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'سریال',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'تامین کننده',
    'tag' => 'برچسب',
    'test_email' => 'ایمیل تست از Snipe-IT',
    'test_mail_text' => 'این آزمون از سیستم مدیریت دارایی Snipe-IT است. اگر شما این کار را کردید، ایمیل کار می کند :)',
    'the_following_item' => 'مورد زیر مورد بررسی قرار گرفته است:',
    'to_reset' => 'برای بازنشانی: رمز عبور وب، این فرم را تکمیل کنید:',
    'type' => 'تایپ کنید',
    'upcoming-audits' => 'دارایی :count وجود دارد که در روزهای :threshold برای حسابرسی ارائه می شود.',
    'user' => 'کاربر',
    'username' => 'نام کاربری',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'خوش آمدید نام',
    'welcome_to' => 'به وب سایت خوش آمدید',
    'your_assets' => 'دارایی های خود را مشاهده کنید
',
    'your_credentials' => 'مدارک Snipe-IT شما',
    'mail_sent' => 'Mail sent successfully!',
];
